tlslite.constants.CertificateType

Package tlslite :: Module constants :: Class CertificateType |
[show private | hide private]
[frames | no frames]

## Class CertificateType

Class Variable Summary
`int` | `cryptoID` = 2
`int` | `openpgp` = 1
`int` | `x509` = 0

Class Variable Details

    ### cryptoID Type: `int` Value:
        2

    ### openpgp Type: `int` Value:
        1

    ### x509 Type: `int` Value:
        0

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net